@@ -8,16 +8,17 @@ mod xml;
 pub use self::xml::{XMLCommand, XMLCommandKind};
 use crate::{
     command::{escaped::EscapedCommand, external::ExternalCommand, normal::NormalCommand},
-    nodes::{Array, Literal, MaybeRanged, Object, Value},
-    ASTKind, ASTNode,
+    nodes::{Literal, MaybeRanged},
+    value::*,
+    ASTKind, ASTNode, Value,
 };
 use num::BigUint;
 use std::ops::Range;
 
 #[derive(Clone, Debug, Default, Eq, PartialEq)]
 pub struct CommandOptions {
-    args: Array,
-    kvs: Object,
+    args: SparseArray,
+    kvs: OrderedMap,
 }
 
 #[derive(Clone, Default, Eq, PartialEq)]
