@@ -35,7 +35,7 @@ pub enum HyperLinkTarget {
 
 impl HyperLink {
     #[inline]
-    pub fn into_node(self, range: Option<OffsetRange>) -> ASTNode {
+    pub fn into_node(self, range: MaybeRanged) -> ASTNode {
         SmartLink::Normal(box self).into_node(range)
     }
     #[inline]
